@@ -21,6 +21,7 @@ import (
 	"strings"
 	"sync"
 
+	"github.com/casbin/casbin/v3/detector"
 	"github.com/casbin/casbin/v3/effector"
 	"github.com/casbin/casbin/v3/log"
 	"github.com/casbin/casbin/v3/model"
@@ -46,6 +47,8 @@ type Enforcer struct {
 	rmMap      map[string]rbac.RoleManager
 	condRmMap  map[string]rbac.ConditionalRoleManager
 	matcherMap sync.Map
+	logger     log.Logger
+	detectors  []detector.Detector
 
 	enabled              bool
 	autoSave             bool
@@ -54,7 +57,7 @@ type Enforcer struct {
 	autoNotifyDispatcher bool
 	acceptJsonRequest    bool
 
-	logger log.Logger
+	aiConfig AIConfig
 }
 
 // EnforceContext is used as the first element of the parameter "rvals" in method "enforce".
@@ -80,25 +83,10 @@ func (e EnforceContext) GetCacheKey() string {
 //	a := mysqladapter.NewDBAdapter("mysql", "mysql_username:mysql_password@tcp(127.0.0.1:3306)/")
 //	e := casbin.NewEnforcer("path/to/basic_model.conf", a)
 func NewEnforcer(params ...interface{}) (*Enforcer, error) {
-	e := &Enforcer{logger: &log.DefaultLogger{}}
+	e := &Enforcer{}
 
 	parsedParamLen := 0
 	paramLen := len(params)
-	if paramLen >= 1 {
-		enableLog, ok := params[paramLen-1].(bool)
-		if ok {
-			e.EnableLog(enableLog)
-			parsedParamLen++
-		}
-	}
-
-	if paramLen-parsedParamLen >= 1 {
-		logger, ok := params[paramLen-parsedParamLen-1].(log.Logger)
-		if ok {
-			e.logger = logger
-			parsedParamLen++
-		}
-	}
 
 	switch paramLen - parsedParamLen {
 	case 2:
@@ -176,7 +164,6 @@ func (e *Enforcer) InitWithModelAndAdapter(m model.Model, adapter persist.Adapte
 	e.adapter = adapter
 
 	e.model = m
-	m.SetLogger(e.logger)
 	e.model.PrintModel()
 	e.fm = model.LoadFunctionMap()
 
@@ -194,18 +181,6 @@ func (e *Enforcer) InitWithModelAndAdapter(m model.Model, adapter persist.Adapte
 	return nil
 }
 
-// SetLogger changes the current enforcer's logger.
-func (e *Enforcer) SetLogger(logger log.Logger) {
-	e.logger = logger
-	e.model.SetLogger(e.logger)
-	for k := range e.rmMap {
-		e.rmMap[k].SetLogger(e.logger)
-	}
-	for k := range e.condRmMap {
-		e.condRmMap[k].SetLogger(e.logger)
-	}
-}
-
 func (e *Enforcer) initialize() {
 	e.rmMap = map[string]rbac.RoleManager{}
 	e.condRmMap = map[string]rbac.ConditionalRoleManager{}
@@ -219,6 +194,11 @@ func (e *Enforcer) initialize() {
 	e.autoNotifyWatcher = true
 	e.autoNotifyDispatcher = true
 	e.initRmMap()
+
+	// Initialize detectors with default detector if not already set
+	if e.detectors == nil {
+		e.detectors = []detector.Detector{detector.NewDefaultDetector()}
+	}
 }
 
 // LoadModel reloads the model from the model CONF file.
@@ -229,7 +209,6 @@ func (e *Enforcer) LoadModel() error {
 	if err != nil {
 		return err
 	}
-	e.model.SetLogger(e.logger)
 
 	e.model.PrintModel()
 	e.fm = model.LoadFunctionMap()
@@ -249,7 +228,6 @@ func (e *Enforcer) SetModel(m model.Model) {
 	e.model = m
 	e.fm = model.LoadFunctionMap()
 
-	e.model.SetLogger(e.logger)
 	e.initialize()
 }
 
@@ -314,6 +292,62 @@ func (e *Enforcer) SetEffector(eft effector.Effector) {
 	e.eft = eft
 }
 
+// SetLogger sets the logger for the enforcer.
+func (e *Enforcer) SetLogger(logger log.Logger) {
+	e.logger = logger
+}
+
+// SetDetector sets a single detector for the enforcer.
+func (e *Enforcer) SetDetector(d detector.Detector) {
+	e.detectors = []detector.Detector{d}
+}
+
+// SetDetectors sets multiple detectors for the enforcer.
+func (e *Enforcer) SetDetectors(detectors []detector.Detector) {
+	e.detectors = detectors
+}
+
+// RunDetections runs all detectors on all role managers.
+// Returns the first error encountered, or nil if all checks pass.
+// Silently skips role managers that don't support the required iteration methods.
+func (e *Enforcer) RunDetections() error {
+	if e.detectors == nil || len(e.detectors) == 0 {
+		return nil
+	}
+
+	// Run detectors on all role managers
+	for _, rm := range e.rmMap {
+		for _, d := range e.detectors {
+			err := d.Check(rm)
+			// Skip if the role manager doesn't support the required iteration or is not initialized
+			if err != nil && (strings.Contains(err.Error(), "does not support Range iteration") ||
+				strings.Contains(err.Error(), "not properly initialized")) {
+				continue
+			}
+			if err != nil {
+				return err
+			}
+		}
+	}
+
+	// Run detectors on all conditional role managers
+	for _, crm := range e.condRmMap {
+		for _, d := range e.detectors {
+			err := d.Check(crm)
+			// Skip if the role manager doesn't support the required iteration or is not initialized
+			if err != nil && (strings.Contains(err.Error(), "does not support Range iteration") ||
+				strings.Contains(err.Error(), "not properly initialized")) {
+				continue
+			}
+			if err != nil {
+				return err
+			}
+		}
+	}
+
+	return nil
+}
+
 // ClearPolicy clears all policy.
 func (e *Enforcer) ClearPolicy() {
 	e.invalidateMatcherMap()
@@ -327,14 +361,27 @@ func (e *Enforcer) ClearPolicy() {
 
 // LoadPolicy reloads the policy from file/database.
 func (e *Enforcer) LoadPolicy() error {
+	logEntry := e.onLogBeforeEventInLoadPolicy()
+
 	newModel, err := e.loadPolicyFromAdapter(e.model)
 	if err != nil {
+		e.onLogAfterEventWithError(logEntry, err)
 		return err
 	}
 	err = e.applyModifiedModel(newModel)
 	if err != nil {
+		e.onLogAfterEventWithError(logEntry, err)
 		return err
 	}
+
+	e.onLogAfterEventInLoadPolicy(logEntry, newModel)
+
+	// Run detectors after all policy rules are loaded
+	err = e.RunDetections()
+	if err != nil {
+		return err
+	}
+
 	return nil
 }
 
@@ -478,12 +525,20 @@ func (e *Enforcer) IsFiltered() bool {
 
 // SavePolicy saves the current policy (usually after changed with Casbin API) back to file/database.
 func (e *Enforcer) SavePolicy() error {
+	logEntry := e.onLogBeforeEventInSavePolicy()
+
 	if e.IsFiltered() {
-		return errors.New("cannot save a filtered policy")
-	}
-	if err := e.adapter.SavePolicy(e.model); err != nil {
+		err := errors.New("cannot save a filtered policy")
+		e.onLogAfterEventWithError(logEntry, err)
 		return err
 	}
+	if err := e.adapter.SavePolicy(e.model); err != nil {
+		e.onLogAfterEventWithError(logEntry, err)
+		return err
+	}
+
+	e.onLogAfterEventInSavePolicy(logEntry)
+
 	if e.watcher != nil {
 		var err error
 		if watcher, ok := e.watcher.(persist.WatcherEx); ok {
@@ -557,16 +612,6 @@ func (e *Enforcer) EnableEnforce(enable bool) {
 	e.enabled = enable
 }
 
-// EnableLog changes whether Casbin will log messages to the Logger.
-func (e *Enforcer) EnableLog(enable bool) {
-	e.logger.EnableLog(enable)
-}
-
-// IsLogEnabled returns the current logger's enabled status.
-func (e *Enforcer) IsLogEnabled() bool {
-	return e.logger.IsEnabled()
-}
-
 // EnableAutoNotifyWatcher controls whether to save a policy rule automatically notify the Watcher when it is added or removed.
 func (e *Enforcer) EnableAutoNotifyWatcher(enable bool) {
 	e.autoNotifyWatcher = enable
@@ -636,10 +681,16 @@ func (e *Enforcer) invalidateMatcherMap() {
 
 // enforce use a custom matcher to decides whether a "subject" can access a "object" with the operation "action", input parameters are usually: (matcher, sub, obj, act), use model matcher by default when matcher is "".
 func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interface{}) (ok bool, err error) { //nolint:funlen,cyclop,gocyclo // TODO: reduce function complexity
+	logEntry := e.onLogBeforeEventInEnforce(rvals)
+
 	defer func() {
 		if r := recover(); r != nil {
 			err = fmt.Errorf("panic: %v\n%s", r, debug.Stack())
+			if e.logger != nil && logEntry != nil {
+				logEntry.Error = err
+			}
 		}
+		e.onLogAfterEventInEnforce(logEntry, ok)
 	}()
 
 	if !e.enabled {
@@ -840,16 +891,9 @@ func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interfac
 		}
 	}
 
-	var logExplains [][]string
-
 	if explains != nil {
-		if len(*explains) > 0 {
-			logExplains = append(logExplains, *explains)
-		}
-
 		if explainIndex != -1 && len(e.model["p"][pType].Policy) > explainIndex {
 			*explains = e.model["p"][pType].Policy[explainIndex]
-			logExplains = append(logExplains, *explains)
 		}
 	}
 
@@ -858,7 +902,6 @@ func (e *Enforcer) enforce(matcher string, explains *[]string, rvals ...interfac
 	if effect == effector.Allow {
 		result = true
 	}
-	e.logger.LogEnforce(expString, rvals, result, logExplains)
 
 	return result, nil
 }
