@@ -41,6 +41,7 @@ type IEnforcer interface {
 	GetRoleManager() rbac.RoleManager
 	SetRoleManager(rm rbac.RoleManager)
 	SetEffector(eft effector.Effector)
+	SetAIConfig(config AIConfig)
 	ClearPolicy()
 	LoadPolicy() error
 	LoadFilteredPolicy(filter interface{}) error
@@ -48,7 +49,6 @@ type IEnforcer interface {
 	IsFiltered() bool
 	SavePolicy() error
 	EnableEnforce(enable bool)
-	EnableLog(enable bool)
 	EnableAutoNotifyWatcher(enable bool)
 	EnableAutoSave(autoSave bool)
 	EnableAutoBuildRoleLinks(autoBuildRoleLinks bool)
@@ -59,6 +59,7 @@ type IEnforcer interface {
 	EnforceExWithMatcher(matcher string, rvals ...interface{}) (bool, []string, error)
 	BatchEnforce(requests [][]interface{}) ([]bool, error)
 	BatchEnforceWithMatcher(matcher string, requests [][]interface{}) ([]bool, error)
+	Explain(rvals ...interface{}) (string, error)
 
 	/* RBAC API */
 	GetRolesForUser(name string, domain ...string) ([]string, error)
@@ -102,6 +103,7 @@ type IEnforcer interface {
 	GetAllNamedActions(ptype string) ([]string, error)
 	GetAllRoles() ([]string, error)
 	GetAllNamedRoles(ptype string) ([]string, error)
+	GetAllUsers() ([]string, error)
 	GetPolicy() ([][]string, error)
 	GetFilteredPolicy(fieldIndex int, fieldValues ...string) ([][]string, error)
 	GetNamedPolicy(ptype string) ([][]string, error)
