@@ -285,6 +285,13 @@ func (e *SyncedEnforcer) GetAllNamedRoles(ptype string) ([]string, error) {
 	return e.Enforcer.GetAllNamedRoles(ptype)
 }
 
+// GetAllUsers gets the list of users that show up in the current policy.
+func (e *SyncedEnforcer) GetAllUsers() ([]string, error) {
+	e.m.RLock()
+	defer e.m.RUnlock()
+	return e.Enforcer.GetAllUsers()
+}
+
 // GetPolicy gets all the authorization rules in the policy.
 func (e *SyncedEnforcer) GetPolicy() ([][]string, error) {
 	e.m.RLock()
