@@ -38,7 +38,7 @@ func BenchmarkRaw(b *testing.B) {
 }
 
 func BenchmarkBasicModel(b *testing.B) {
-	e, _ := NewEnforcer("examples/basic_model.conf", "examples/basic_policy.csv", false)
+	e, _ := NewEnforcer("examples/basic_model.conf", "examples/basic_policy.csv")
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
@@ -47,7 +47,7 @@ func BenchmarkBasicModel(b *testing.B) {
 }
 
 func BenchmarkRBACModel(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_model.conf", "examples/rbac_policy.csv", false)
+	e, _ := NewEnforcer("examples/rbac_model.conf", "examples/rbac_policy.csv")
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
@@ -69,7 +69,7 @@ func BenchmarkRBACModelSizes(b *testing.B) {
 	for _, c := range cases {
 		c := c
 
-		e, err := NewEnforcer("examples/rbac_model.conf", false)
+		e, err := NewEnforcer("examples/rbac_model.conf")
 		if err != nil {
 			b.Fatal(err)
 		}
@@ -125,7 +125,7 @@ func BenchmarkRBACModelSizes(b *testing.B) {
 }
 
 func BenchmarkRBACModelSmall(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_model.conf", false)
+	e, _ := NewEnforcer("examples/rbac_model.conf")
 
 	// 100 roles, 10 resources.
 	for i := 0; i < 100; i++ {
@@ -150,7 +150,7 @@ func BenchmarkRBACModelSmall(b *testing.B) {
 }
 
 func BenchmarkRBACModelMedium(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_model.conf", false)
+	e, _ := NewEnforcer("examples/rbac_model.conf")
 
 	// 1000 roles, 100 resources.
 	pPolicies := make([][]string, 0)
@@ -181,7 +181,7 @@ func BenchmarkRBACModelMedium(b *testing.B) {
 }
 
 func BenchmarkRBACModelLarge(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_model.conf", false)
+	e, _ := NewEnforcer("examples/rbac_model.conf")
 
 	// 10000 roles, 1000 resources.
 	pPolicies := make([][]string, 0)
@@ -212,7 +212,7 @@ func BenchmarkRBACModelLarge(b *testing.B) {
 }
 
 func BenchmarkRBACModelWithResourceRoles(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_with_resource_roles_model.conf", "examples/rbac_with_resource_roles_policy.csv", false)
+	e, _ := NewEnforcer("examples/rbac_with_resource_roles_model.conf", "examples/rbac_with_resource_roles_policy.csv")
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
@@ -221,7 +221,7 @@ func BenchmarkRBACModelWithResourceRoles(b *testing.B) {
 }
 
 func BenchmarkRBACModelWithDomains(b *testing.B) {
-	e, _ := NewEnforcer("examples/rbac_with_domains_model.conf", "examples/rbac_with_domains_policy.csv", false)
+	e, _ := NewEnforcer("examples/rbac_with_domains_model.conf", "examples/rbac_with_domains_policy.csv")
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
@@ -230,7 +230,7 @@ func BenchmarkRBACModelWithDomains(b *testing.B) {
 }
 
 func BenchmarkABACModel(b *testing.B) {
-	e, _ := NewEnforcer("examples/abac_model.conf", false)
+	e, _ := NewEnforcer("examples/abac_model.conf")
 	data1 := newTestResource("data1", "alice")
 
 	b.ResetTimer()
@@ -240,7 +240,7 @@ func BenchmarkABACModel(b *testing.B) {
 }
 
 func BenchmarkABACRuleModel(b *testing.B) {
-	e, _ := NewEnforcer("examples/abac_rule_model.conf", false)
+	e, _ := NewEnforcer("examples/abac_rule_model.conf")
 	sub := newTestSubject("alice", 18)
 
 	for i := 0; i < 1000; i++ {
@@ -254,7 +254,7 @@ func BenchmarkABACRuleModel(b *testing.B) {
 }
 
 func BenchmarkKeyMatchModel(b *testing.B) {
-	e, _ := NewEnforcer("examples/keymatch_model.conf", "examples/keymatch_policy.csv", false)
+	e, _ := NewEnforcer("examples/keymatch_model.conf", "examples/keymatch_policy.csv")
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
