@@ -16,11 +16,8 @@ package defaultrolemanager
 
 import (
 	"errors"
-	"fmt"
-	"strings"
 	"sync"
 
-	"github.com/casbin/casbin/v3/log"
 	"github.com/casbin/casbin/v3/rbac"
 	"github.com/casbin/casbin/v3/util"
 )
@@ -119,36 +116,6 @@ func (r *Role) rangeUsers(fn func(key, value interface{}) bool) {
 	})
 }
 
-func (r *Role) toString() string {
-	roles := r.getRoles()
-
-	if len(roles) == 0 {
-		return ""
-	}
-
-	var sb strings.Builder
-	sb.WriteString(r.name)
-	sb.WriteString(" < ")
-	if len(roles) != 1 {
-		sb.WriteString("(")
-	}
-
-	for i, role := range roles {
-		if i == 0 {
-			sb.WriteString(role)
-		} else {
-			sb.WriteString(", ")
-			sb.WriteString(role)
-		}
-	}
-
-	if len(roles) != 1 {
-		sb.WriteString(")")
-	}
-
-	return sb.String()
-}
-
 func (r *Role) getRoles() []string {
 	var names []string
 	r.rangeRoles(func(key, value interface{}) bool {
@@ -202,7 +169,6 @@ type RoleManagerImpl struct {
 	maxHierarchyLevel  int
 	matchingFunc       rbac.MatchingFunc
 	domainMatchingFunc rbac.MatchingFunc
-	logger             log.Logger
 	matchingFuncCache  *util.SyncLRUCache
 	mutex              sync.Mutex
 }
@@ -213,7 +179,6 @@ func NewRoleManagerImpl(maxHierarchyLevel int) *RoleManagerImpl {
 	rm := RoleManagerImpl{}
 	_ = rm.Clear() // init allRoles and matchingFuncCache
 	rm.maxHierarchyLevel = maxHierarchyLevel
-	rm.SetLogger(&log.DefaultLogger{})
 	return &rm
 }
 
@@ -315,11 +280,6 @@ func (rm *RoleManagerImpl) AddDomainMatchingFunc(name string, fn rbac.MatchingFu
 	rm.domainMatchingFunc = fn
 }
 
-// SetLogger sets role manager's logger.
-func (rm *RoleManagerImpl) SetLogger(logger log.Logger) {
-	rm.logger = logger
-}
-
 // Clear clears all stored data and resets the role manager to the initial state.
 func (rm *RoleManagerImpl) Clear() error {
 	rm.matchingFuncCache = util.NewSyncLRUCache(100)
@@ -480,27 +440,9 @@ func (rm *RoleManagerImpl) getImplicitUsersHelper(users map[string]*Role, userSe
 	return rm.getImplicitUsersHelper(nextUsers, userSet, res, level+1)
 }
 
-func (rm *RoleManagerImpl) toString() []string {
-	var roles []string
-
-	rm.allRoles.Range(func(key, value interface{}) bool {
-		role := value.(*Role)
-		if text := role.toString(); text != "" {
-			roles = append(roles, text)
-		}
-		return true
-	})
-
-	return roles
-}
-
 // PrintRoles prints all the roles to log.
 func (rm *RoleManagerImpl) PrintRoles() error {
-	if !(rm.logger).IsEnabled() {
-		return nil
-	}
-	roles := rm.toString()
-	rm.logger.LogRole(roles)
+	// Logger has been removed - this is now a no-op
 	return nil
 }
 
@@ -548,7 +490,6 @@ type DomainManager struct {
 	maxHierarchyLevel  int
 	matchingFunc       rbac.MatchingFunc
 	domainMatchingFunc rbac.MatchingFunc
-	logger             log.Logger
 	matchingFuncCache  *util.SyncLRUCache
 }
 
@@ -561,11 +502,6 @@ func NewDomainManager(maxHierarchyLevel int) *DomainManager {
 	return dm
 }
 
-// SetLogger sets role manager's logger.
-func (dm *DomainManager) SetLogger(logger log.Logger) {
-	dm.logger = logger
-}
-
 // AddMatchingFunc support use pattern in g.
 func (dm *DomainManager) AddMatchingFunc(name string, fn rbac.MatchingFunc) {
 	dm.matchingFunc = fn
@@ -754,28 +690,9 @@ func (dm *DomainManager) GetImplicitUsers(name string, domains ...string) ([]str
 	return rm.GetImplicitUsers(name, domains...)
 }
 
-func (dm *DomainManager) toString() []string {
-	var roles []string
-
-	dm.rmMap.Range(func(key, value interface{}) bool {
-		domain := key.(string)
-		rm := value.(*RoleManagerImpl)
-		domainRoles := rm.toString()
-		roles = append(roles, fmt.Sprintf("%s: %s", domain, strings.Join(domainRoles, ", ")))
-		return true
-	})
-
-	return roles
-}
-
 // PrintRoles prints all the roles to log.
 func (dm *DomainManager) PrintRoles() error {
-	if !(dm.logger).IsEnabled() {
-		return nil
-	}
-
-	roles := dm.toString()
-	dm.logger.LogRole(roles)
+	// Logger has been removed - this is now a no-op
 	return nil
 }
 
@@ -857,7 +774,6 @@ func NewConditionalRoleManager(maxHierarchyLevel int) *ConditionalRoleManager {
 	rm := ConditionalRoleManager{}
 	_ = rm.Clear() // init allRoles and matchingFuncCache
 	rm.maxHierarchyLevel = maxHierarchyLevel
-	rm.SetLogger(&log.DefaultLogger{})
 	return &rm
 }
 
@@ -908,7 +824,7 @@ func (crm *ConditionalRoleManager) getNextRoles(currentRole, nextRole *Role, dom
 	passLinkConditionFunc, err := crm.checkLinkCondition(currentRole.name, nextRole.name, domains)
 
 	if err != nil {
-		crm.logger.LogError(err, "hasLinkHelper LinkCondition Error")
+		// Logger has been removed - error is ignored
 		return false
 	}
 
@@ -948,7 +864,7 @@ func (crm *ConditionalRoleManager) GetRoles(name string, domains ...string) ([]s
 		roleName := key.(string)
 		passLinkConditionFunc, err := crm.checkLinkCondition(name, roleName, domains)
 		if err != nil {
-			crm.logger.LogError(err, "getRoles LinkCondition Error")
+			// Logger has been removed - error is ignored
 			return true
 		}
 
@@ -972,7 +888,7 @@ func (crm *ConditionalRoleManager) GetUsers(name string, domains ...string) ([]s
 
 		passLinkConditionFunc, err := crm.checkLinkCondition(userName, name, domains)
 		if err != nil {
-			crm.logger.LogError(err, "getUsers LinkCondition Error")
+			// Logger has been removed - error is ignored
 			return true
 		}
 
@@ -1029,7 +945,7 @@ func (crm *ConditionalRoleManager) getImplicitRolesHelper(roles map[string]*Role
 			if _, ok := roleSet[roleName]; !ok {
 				passLinkConditionFunc, err := crm.checkLinkCondition(role.name, roleName, domains)
 				if err != nil {
-					crm.logger.LogError(err, "getImplicitRoles LinkCondition Error")
+					// Logger has been removed - error is ignored
 					return true
 				}
 
@@ -1059,7 +975,7 @@ func (crm *ConditionalRoleManager) getImplicitUsersHelper(users map[string]*Role
 			if _, ok := userSet[userName]; !ok {
 				passLinkConditionFunc, err := crm.checkLinkCondition(userName, user.name, domains)
 				if err != nil {
-					crm.logger.LogError(err, "getImplicitUsers LinkCondition Error")
+					// Logger has been removed - error is ignored
 					return true
 				}
 
@@ -1163,7 +1079,6 @@ func NewConditionalDomainManager(maxHierarchyLevel int) *ConditionalDomainManage
 	rm := ConditionalDomainManager{}
 	_ = rm.Clear() // init allRoles and matchingFuncCache
 	rm.maxHierarchyLevel = maxHierarchyLevel
-	rm.SetLogger(&log.DefaultLogger{})
 	return &rm
 }
 
